cmdrun

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(name string, args ...string) (string, string, error)

Run executes a command in the current working directory and returns trimmed stdout, stderr, and error.

func RunIn

func RunIn(dir, name string, args ...string) (string, string, error)

RunIn executes a command in dir (or the current working directory if dir is empty) and returns trimmed stdout, stderr, and error.

func RunQuiet

func RunQuiet(name string, args ...string) error

RunQuiet executes a command, discards all output, and returns only the error.

func RunWithOutput

func RunWithOutput(name string, args ...string) error

RunWithOutput executes a command and pipes output directly to stdout/stderr.

Types

This section is empty.

Jump to