ui

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrCancelled = errors.New("cancelled")

ErrCancelled is returned when the user cancels a selection or confirmation (Ctrl+C or ESC).

Functions

func Confirm

func Confirm(prompt string, defaultYes bool) (bool, error)

Confirm asks a yes/no question via the fuzzyfinder library.

func PrintHeader

func PrintHeader(message string)

PrintHeader prints a dim header line.

func Select

func Select(prompt string, options []string, initialQuery ...string) (string, error)

Select presents options via the fuzzyfinder library and returns the selected item.

Types

This section is empty.

Jump to