Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Run ¶
Run executes a command in the current working directory and returns trimmed stdout, stderr, and error.
func RunIn ¶
RunIn executes a command in dir (or the current working directory if dir is empty) and returns trimmed stdout, stderr, and error.
func RunWithOutput ¶
RunWithOutput executes a command and pipes output directly to stdout/stderr.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.